==> RsSmw-4.90.49.53-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Tetra/FilterPy/Parameter/Cosine.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cosine:
	"""Cosine commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cosine", core, parent)

	def get_cofs(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:TETRa:FILTer:PARameter:COSine:COFS \n
		Snippet: value: float = driver.source.bb.tetra.filterPy.parameter.cosine.get_cofs() \n
		Sets the value for the cut off frequency shift. The cut off frequency of the cosine filter can be adjusted to reach
		spectrum mask requirements. \n
			:return: cofs: float Range: -1 to 1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TETRa:FILTer:PARameter:COSine:COFS?')
		return Conversions.str_to_float(response)

	def set_cofs(self, cofs: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:TETRa:FILTer:PARameter:COSine:COFS \n
		Snippet: driver.source.bb.tetra.filterPy.parameter.cosine.set_cofs(cofs = 1.0) \n
		Sets the value for the cut off frequency shift. The cut off frequency of the cosine filter can be adjusted to reach
		spectrum mask requirements. \n
			:param cofs: float Range: -1 to 1
		"""
		param = Conversions.decimal_value_to_str(cofs)
		self._core.io.write(f'SOURce<HwInstance>:BB:TETRa:FILTer:PARameter:COSine:COFS {param}')

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:TETRa:FILTer:PARameter:COSine \n
		Snippet: value: float = driver.source.bb.tetra.filterPy.parameter.cosine.get_value() \n
		Sets the filter parameter. \n
			:return: cosine: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TETRa:FILTer:PARameter:COSine?')
		return Conversions.str_to_float(response)

	def set_value(self, cosine: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:TETRa:FILTer:PARameter:COSine \n
		Snippet: driver.source.bb.tetra.filterPy.parameter.cosine.set_value(cosine = 1.0) \n
		Sets the filter parameter. \n
			:param cosine: float Range: 0.05 to 0.99
		"""
		param = Conversions.decimal_value_to_str(cosine)
		self._core.io.write(f'SOURce<HwInstance>:BB:TETRa:FILTer:PARameter:COSine {param}')

==> RsSmw-5.0.44.58-py3-none-any.whl: RsSmw/Implementations/Source/Bb/Tetra/FilterPy/Parameter/Cosine.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cosine:
	"""Cosine commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("cosine", core, parent)

	def get_cofs(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:TETRa:FILTer:PARameter:COSine:COFS \n
		Snippet: value: float = driver.source.bb.tetra.filterPy.parameter.cosine.get_cofs() \n
		Sets the value for the cut off frequency shift. The cut off frequency of the cosine filter can be adjusted to reach
		spectrum mask requirements. \n
			:return: cofs: float Range: -1 to 1
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TETRa:FILTer:PARameter:COSine:COFS?')
		return Conversions.str_to_float(response)

	def set_cofs(self, cofs: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:TETRa:FILTer:PARameter:COSine:COFS \n
		Snippet: driver.source.bb.tetra.filterPy.parameter.cosine.set_cofs(cofs = 1.0) \n
		Sets the value for the cut off frequency shift. The cut off frequency of the cosine filter can be adjusted to reach
		spectrum mask requirements. \n
			:param cofs: float Range: -1 to 1
		"""
		param = Conversions.decimal_value_to_str(cofs)
		self._core.io.write(f'SOURce<HwInstance>:BB:TETRa:FILTer:PARameter:COSine:COFS {param}')

	def get_value(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:TETRa:FILTer:PARameter:COSine \n
		Snippet: value: float = driver.source.bb.tetra.filterPy.parameter.cosine.get_value() \n
		Sets the filter parameter. \n
			:return: cosine: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:TETRa:FILTer:PARameter:COSine?')
		return Conversions.str_to_float(response)

	def set_value(self, cosine: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:TETRa:FILTer:PARameter:COSine \n
		Snippet: driver.source.bb.tetra.filterPy.parameter.cosine.set_value(cosine = 1.0) \n
		Sets the filter parameter. \n
			:param cosine: float Range: 0.05 to 0.99
		"""
		param = Conversions.decimal_value_to_str(cosine)
		self._core.io.write(f'SOURce<HwInstance>:BB:TETRa:FILTer:PARameter:COSine {param}')
